# yalelaundry [![PyPI version](https://badge.fury.io/py/yalelaundry.svg)](https://badge.fury.io/py/yalelaundry)

> Python library for interfacing with the Yale Laundry APIs.

[API documentation](https://developers.yale.edu/laundry-api-group)

## Setup
First, install the module:

```sh
pip3 install yalelaundry
```

Then, to use these functions, you must import the module:

```py
import yalelaundry
```

Before using the library, you must instantiate its class, for example:

```py
laundry = yalelaundry.YaleLaundry('your API key here')
```

You can obtain your API key as described [here](https://developers.yale.edu/how-info/how-do-i-get-access-apis).

## Retrieval Functions
- TODO

See `example.py` for several usage examples.

## Author
[Erik Boesen](https://github.com/ErikBoesen)

## License
[GPL](LICENSE)
